summaryrefslogtreecommitdiffstats
path: root/kwin/bridge.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kwin/bridge.cpp
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwin/bridge.cpp')
-rw-r--r--kwin/bridge.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kwin/bridge.cpp b/kwin/bridge.cpp
index df610dd53..49840e248 100644
--- a/kwin/bridge.cpp
+++ b/kwin/bridge.cpp
@@ -43,7 +43,7 @@ BRIDGE_HELPER( bool, isMovable,,, const )
BRIDGE_HELPER( bool, isResizable,,, const )
BRIDGE_HELPER( TQString, caption,,, const )
BRIDGE_HELPER( void, processMousePressEvent, TQMouseEvent* e, e, )
-BRIDGE_HELPER( TQRect, tqgeometry,,, const )
+BRIDGE_HELPER( TQRect, geometry,,, const )
BRIDGE_HELPER( void, closeWindow,,, )
BRIDGE_HELPER( void, maximize, MaximizeMode m, m, )
BRIDGE_HELPER( void, minimize,,, )
@@ -178,12 +178,12 @@ TQRegion Bridge::unobscuredRegion( const TQRegion& r ) const
if( !(*it)->isOnDesktop( c->desktop()))
continue;
}
/* the clients all have their tqmask-regions in local coords
so we have to translate them to a shared coord system
we choose ours */
int dx = (*it)->x() - c->x();
int dy = (*it)->y() - c->y();
- TQRegion creg = (*it)->tqmask();
+ TQRegion creg = (*it)->mask();
creg.translate(dx, dy);
reg -= creg;
if (reg.isEmpty())
@@ -178,12 +178,12 @@ TQRegion Bridge::unobscuredRegion( const TQRegion& r ) const
continue;
}
- /* the clients all have their tqmask-regions in local coords
+ /* the clients all have their mask-regions in local coords
so we have to translate them to a shared coord system
we choose ours */